<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="pt_BR">
<context>
    <name></name>
    <message>
        <source>Delete</source>
        <translation type="vanished">Excluir</translation>
    </message>
    <message>
        <source>Fullscreen</source>
        <translation type="vanished">Tela cheia</translation>
    </message>
    <message>
        <source>Slide show</source>
        <translation type="vanished">Apresentação de slides</translation>
    </message>
    <message>
        <source>Export</source>
        <translation type="vanished">Exportar</translation>
    </message>
    <message>
        <source>Copy</source>
        <translation type="vanished">Copiar</translation>
    </message>
    <message>
        <source>Favorite</source>
        <translation type="vanished">Favorito</translation>
    </message>
    <message>
        <source>Rotate clockwise</source>
        <translation type="vanished">Girar no sentido horário</translation>
    </message>
    <message>
        <source>Rotate counterclockwise</source>
        <translation type="vanished">Girar no sentido anti-horário</translation>
    </message>
    <message>
        <source>Set as wallpaper</source>
        <translation type="vanished">Definir como papel de parede</translation>
    </message>
    <message>
        <source>Display in file manager</source>
        <translation type="vanished">Exibir no Gerenciador de Arquivos</translation>
    </message>
    <message>
        <source>Photo info</source>
        <translation type="vanished">Informações da foto</translation>
    </message>
    <message>
        <source>Video info</source>
        <translation type="vanished">Detalhes do vídeo</translation>
    </message>
    <message>
        <source>Restore</source>
        <translation type="vanished">Restaurar</translation>
    </message>
</context>
<context>
    <name>AlbumCreateDialog</name>
    <message>
        <source>Unnamed</source>
        <translation>Sem Nome</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>Cancelar</translation>
    </message>
    <message>
        <source>Create</source>
        <translation>Criar</translation>
    </message>
    <message>
        <source>New Album</source>
        <translation>Novo Álbum</translation>
    </message>
</context>
<context>
    <name>AlbumDeleteDialog</name>
    <message>
        <source>Cancel</source>
        <translation>Cancelar</translation>
    </message>
    <message>
        <source>Delete</source>
        <translation>Excluir</translation>
    </message>
    <message>
        <source>Are you sure you want to delete this album?</source>
        <translation>Excluir este álbum?</translation>
    </message>
</context>
<context>
    <name>AlbumLeftTabItem</name>
    <message>
        <source>Trash</source>
        <translation>Lixeira</translation>
    </message>
    <message>
        <source>Favorites</source>
        <translation>Favoritos</translation>
    </message>
    <message>
        <source>Import</source>
        <translation>Importar</translation>
    </message>
</context>
<context>
    <name>AlbumView</name>
    <message>
        <source>Trash</source>
        <translation>Lixeira</translation>
    </message>
    <message>
        <source>Favorites</source>
        <translation>Favoritos</translation>
    </message>
    <message>
        <source>Or drag photos here</source>
        <translation>Ou arraste as fotos até aqui</translation>
    </message>
    <message>
        <source>Import All</source>
        <translation>Importar Tudo</translation>
    </message>
    <message>
        <source>Import to:</source>
        <translation>Importar para:</translation>
    </message>
    <message>
        <source>Import</source>
        <translation>Importar</translation>
    </message>
    <message>
        <source>System Disk</source>
        <translation>Disco do Sistema</translation>
    </message>
    <message>
        <source>Gallery</source>
        <translation>Galeria</translation>
    </message>
    <message>
        <source>Disk is busy, cannot eject now</source>
        <translation>O disco está em uso, e não pode ser ejetado no momento</translation>
    </message>
    <message>
        <source>OK</source>
        <translation>Ok</translation>
    </message>
    <message>
        <source>New album</source>
        <translation>Novo álbum</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>Cancelar</translation>
    </message>
    <message>
        <source>Ignore</source>
        <translation>Ignorar</translation>
    </message>
    <message>
        <source>Loading...</source>
        <translation>Carregando...</translation>
    </message>
    <message>
        <source>The files will be permanently deleted after the days shown on them</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Image classification</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>Application</name>
    <message>
        <source>Album</source>
        <translation>Álbum</translation>
    </message>
</context>
<context>
    <name>CExportImageDialog</name>
    <message>
        <source>Cancel</source>
        <translation>Cancelar</translation>
    </message>
    <message>
        <source>Replace</source>
        <translation>Substituir</translation>
    </message>
    <message>
        <source>Export</source>
        <translation>Exportar</translation>
    </message>
    <message>
        <source>Pictures</source>
        <translation>Imagens</translation>
    </message>
    <message>
        <source>Documents</source>
        <translation>Documentos</translation>
    </message>
    <message>
        <source>Downloads</source>
        <translation>Downloads</translation>
    </message>
    <message>
        <source>Desktop</source>
        <translation>Área de Trabalho</translation>
    </message>
    <message>
        <source>Videos</source>
        <translation>Vídeos</translation>
    </message>
    <message>
        <source>Music</source>
        <translation>Música</translation>
    </message>
    <message>
        <source>Name:</source>
        <translation>Nome:</translation>
    </message>
    <message>
        <source>Save to:</source>
        <translation>Salvar em:</translation>
    </message>
    <message>
        <source>Format:</source>
        <translation>Formato:</translation>
    </message>
    <message>
        <source>Quality:</source>
        <translation>Qualidade:</translation>
    </message>
    <message>
        <source>Save</source>
        <translation>Salvar</translation>
    </message>
    <message>
        <source>gif</source>
        <translation>gif</translation>
    </message>
    <message>
        <source>Select other directories</source>
        <translation>Selecionar outros diretórios</translation>
    </message>
    <message>
        <source>OK</source>
        <translation>Ok</translation>
    </message>
    <message>
        <source>File name cannot be empty</source>
        <translation>O nome de arquivo não pode ficar em branco</translation>
    </message>
    <message>
        <source>already exists. Do you want to replace it?</source>
        <translation>já existe. Substituir?</translation>
    </message>
</context>
<context>
    <name>DBManager</name>
    <message>
        <source>Screen Capture</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Camera</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Draw</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>(copy)</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>DeepinStorage</name>
    <message>
        <source>%1 Drive</source>
        <translation>Unidade %1</translation>
    </message>
    <message>
        <source>Blank %1 Disc</source>
        <translation>Disco em Branco %1</translation>
    </message>
    <message>
        <source>%1 Encrypted</source>
        <translation>Criptografado %1</translation>
    </message>
    <message>
        <source>%1 Volume</source>
        <translation>Volume %1</translation>
    </message>
</context>
<context>
    <name>Exporter</name>
    <message>
        <source>Save</source>
        <translation>Salvar</translation>
    </message>
    <message>
        <source>Export Photos</source>
        <translation>Exportar Fotos</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>Cancelar</translation>
    </message>
</context>
<context>
    <name>ImageEngineApi</name>
    <message>
        <source>Deleting...</source>
        <translation>Excluindo...</translation>
    </message>
    <message>
        <source>Restoring...</source>
        <translation>Restaurando...</translation>
    </message>
    <message>
        <source>Classifying...</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>ImgDeleteDialog</name>
    <message>
        <source>Cancel</source>
        <translation>Cancelar</translation>
    </message>
    <message>
        <source>Delete</source>
        <translation>Excluir</translation>
    </message>
    <message>
        <source>Are you sure you want to permanently delete this file?</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>You cannot restore it any longer</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Are you sure you want to permanently delete %1 files?</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>You cannot restore them any longer</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Are you sure you want to delete this file locally?</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>You can restore it in the trash</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Are you sure you want to delete %1 files locally?</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>You can restore them in the trash</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>ImgInfoDialog</name>
    <message>
        <source>Basic info</source>
        <translation>Informações básicas</translation>
    </message>
    <message>
        <source>Details</source>
        <translation>Detalhes</translation>
    </message>
    <message>
        <source>Image info</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>ImportTimeLineView</name>
    <message>
        <source>Import</source>
        <translation>Importar</translation>
    </message>
    <message>
        <source>1 photo</source>
        <translation>1 foto</translation>
    </message>
    <message>
        <source>1 video</source>
        <translation>1 vídeo</translation>
    </message>
    <message numerus="yes">
        <source>%n photos</source>
        <translation>
            <numerusform>%n foto</numerusform>
            <numerusform>%n fotos</numerusform>
        </translation>
    </message>
    <message numerus="yes">
        <source>%n videos</source>
        <translation>
            <numerusform>%n vídeo</numerusform>
            <numerusform>%n vídeos</numerusform>
        </translation>
    </message>
    <message numerus="yes">
        <source>%n items</source>
        <translation>
            <numerusform>%n item</numerusform>
            <numerusform>%n itens</numerusform>
        </translation>
    </message>
</context>
<context>
    <name>ImportView</name>
    <message>
        <source>Import Photos and Videos</source>
        <translation>Importar Fotos e Vídeos</translation>
    </message>
    <message>
        <source>Or drag them here</source>
        <translation>Ou arraste-o pra cá</translation>
    </message>
    <message>
        <source>All photos and videos</source>
        <translation>Todas as fotos e os vídeos</translation>
    </message>
    <message>
        <source>No photos or videos found</source>
        <translation>Nenhuma foto ou vídeo encontrado</translation>
    </message>
</context>
<context>
    <name>LeftListView</name>
    <message>
        <source>Slide show</source>
        <translation>Apresentação de Slides</translation>
    </message>
    <message>
        <source>Rename</source>
        <translation>Renomear</translation>
    </message>
    <message>
        <source>Export</source>
        <translation>Exportar</translation>
    </message>
    <message>
        <source>Delete</source>
        <translation>Excluir</translation>
    </message>
    <message>
        <source>Device</source>
        <translation>Dispositivo</translation>
    </message>
    <message>
        <source>Gallery</source>
        <translation>Galeria</translation>
    </message>
    <message>
        <source>Albums</source>
        <translation>Álbuns</translation>
    </message>
    <message>
        <source>New album</source>
        <translation>Novo álbum</translation>
    </message>
</context>
<context>
    <name>Main</name>
    <message>
        <source>Album is a fashion manager for viewing and organizing photos and videos.</source>
        <translation>Álbum é um gerenciador elegante para ver e organizar fotos e vídeos.</translation>
    </message>
</context>
<context>
    <name>MainWindow</name>
    <message>
        <source>Photos</source>
        <translation>Fotos</translation>
    </message>
    <message>
        <source>Fullscreen</source>
        <translation>Tela Cheia</translation>
    </message>
    <message>
        <source>Help</source>
        <translation>Ajuda</translation>
    </message>
    <message>
        <source>Display in file manager</source>
        <translation>Exibir no Gerenciador de Arquivos</translation>
    </message>
    <message>
        <source>Slide show</source>
        <translation>Apresentação de Slides</translation>
    </message>
    <message>
        <source>Copy</source>
        <translation>Copiar</translation>
    </message>
    <message>
        <source>Set as wallpaper</source>
        <translation>Definir como papel de parede</translation>
    </message>
    <message>
        <source>Rotate clockwise</source>
        <translation>Girar no sentido horário</translation>
    </message>
    <message>
        <source>Rotate counterclockwise</source>
        <translation>Girar no sentido anti-horário</translation>
    </message>
    <message>
        <source>Previous</source>
        <translation>Anterior</translation>
    </message>
    <message>
        <source>Next</source>
        <translation>Próximo</translation>
    </message>
    <message>
        <source>Favorite</source>
        <translation>Favorito</translation>
    </message>
    <message>
        <source>Unfavorite</source>
        <translation>Remover dos Favoritos</translation>
    </message>
    <message>
        <source>Rename album</source>
        <translation>Renomear álbum</translation>
    </message>
    <message>
        <source>Album “%1” removed</source>
        <translation>Álbum “%1” excluído</translation>
    </message>
    <message>
        <source>Successfully added to “%1”</source>
        <translation>Adicionado em &quot;%1&quot;</translation>
    </message>
    <message>
        <source>Import successful</source>
        <translation>Importação Bem-sucedida</translation>
    </message>
    <message>
        <source>Import failed</source>
        <translation>Falha na importação</translation>
    </message>
    <message>
        <source>Export failed</source>
        <translation>Falha na exportação</translation>
    </message>
    <message>
        <source>Export successful</source>
        <translation>Exportação Bem-sucedida</translation>
    </message>
    <message>
        <source>All Photos</source>
        <translation>Todas as Fotos</translation>
    </message>
    <message>
        <source>Timelines</source>
        <translation>Linhas do Tempo</translation>
    </message>
    <message>
        <source>Albums</source>
        <translation>Álbuns</translation>
    </message>
    <message>
        <source>Exit fullscreen/slideshow</source>
        <translation>Sair da Tela Cheia / Apresentação de Slides</translation>
    </message>
    <message>
        <source>Display shortcuts</source>
        <translation>Exibir atalhos</translation>
    </message>
    <message>
        <source>View</source>
        <translation>Visualizar</translation>
    </message>
    <message>
        <source>Select all</source>
        <translation>Selecionar tudo</translation>
    </message>
    <message>
        <source>Zoom in</source>
        <translation>Aumentar zoom</translation>
    </message>
    <message>
        <source>Zoom out</source>
        <translation>Reduzir zoom</translation>
    </message>
    <message>
        <source>New album</source>
        <translation>Novo álbum</translation>
    </message>
    <message>
        <source>Page up</source>
        <translation>Página acima</translation>
    </message>
    <message>
        <source>Page down</source>
        <translation>Página abaixo</translation>
    </message>
    <message>
        <source>Settings</source>
        <translation>Configurações</translation>
    </message>
    <message>
        <source>Importing...</source>
        <translation>Importando...</translation>
    </message>
    <message>
        <source>All photos and videos</source>
        <translation>Todas fotos e vídeos</translation>
    </message>
    <message>
        <source>Import Photos and Videos</source>
        <translation>Importar Fotos e Vídeos</translation>
    </message>
    <message>
        <source>No photos or videos found</source>
        <translation>Nenhuma foto ou vídeo encontrado</translation>
    </message>
    <message>
        <source>Export photos</source>
        <translation>Exportar fotos</translation>
    </message>
    <message>
        <source>Import photos/videos</source>
        <translation>Importar fotos/vídeos</translation>
    </message>
    <message>
        <source>Delete</source>
        <translation>Excluir</translation>
    </message>
    <message>
        <source>Photo/Video info</source>
        <translation>Informações da foto/vídeo</translation>
    </message>
    <message>
        <source>Import photos and videos</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Import folders</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Import interrupted</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Cannot add this path, please try another one</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>The path already exists</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Failed to restore %1 files: file name too long</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Classifying...</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>MetadataName</name>
    <message>
        <source>Flash</source>
        <translation>Flash</translation>
    </message>
    <message>
        <source>Type</source>
        <translation>Tipo</translation>
    </message>
    <message>
        <source>File size</source>
        <translation>Tamanho do arquivo</translation>
    </message>
    <message>
        <source>Dimensions</source>
        <translation>Dimensões</translation>
    </message>
    <message>
        <source>Date captured</source>
        <translation>Data de captura</translation>
    </message>
    <message>
        <source>Date modified</source>
        <translation>Última modificação</translation>
    </message>
    <message>
        <source>Exposure mode</source>
        <translation>Modo de exposição</translation>
    </message>
    <message>
        <source>Exposure program</source>
        <translation>Programa de exposição</translation>
    </message>
    <message>
        <source>Exposure time</source>
        <translation>Tempo de exposição</translation>
    </message>
    <message>
        <source>Aperture</source>
        <translation>Abertura</translation>
    </message>
    <message>
        <source>Focal length</source>
        <translation>Distância focal</translation>
    </message>
    <message>
        <source>ISO</source>
        <translation>ISO</translation>
    </message>
    <message>
        <source>Max aperture</source>
        <translation>Abertura máxima</translation>
    </message>
    <message>
        <source>Metering mode</source>
        <translation>Modo de medida</translation>
    </message>
    <message>
        <source>White balance</source>
        <translation>Balanço de branco</translation>
    </message>
    <message>
        <source>Flash compensation</source>
        <translation>Compensação do flash</translation>
    </message>
    <message>
        <source>Camera model</source>
        <translation>Modelo de câmera</translation>
    </message>
    <message>
        <source>Lens model</source>
        <translation>Modelo de lente</translation>
    </message>
    <message>
        <source>Colorspace</source>
        <translation>Espaço de Cores</translation>
    </message>
    <message>
        <source>Tag</source>
        <translation>Rótulo</translation>
    </message>
    <message>
        <source>Name</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>NoResultWidget</name>
    <message>
        <source>No results</source>
        <translation>Não há resultados</translation>
    </message>
</context>
<context>
    <name>PathManager</name>
    <message>
        <source>System Disk</source>
        <translation>Disco do Sistema</translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <source>Select</source>
        <translation>Selecionar</translation>
    </message>
    <message>
        <source>Unselect</source>
        <translation>Desmarcar</translation>
    </message>
    <message>
        <source>%1/%2/%3</source>
        <translation>%1/%2/%3</translation>
    </message>
    <message>
        <source>Imported on</source>
        <translation>Importado em</translation>
    </message>
    <message>
        <source> %1-%2-%3 %4</source>
        <translation> %3-%2-%1 %4</translation>
    </message>
    <message>
        <source>Imported on </source>
        <translation>Importado em</translation>
    </message>
    <message>
        <source>Select All</source>
        <translation>Selecionar tudo</translation>
    </message>
    <message>
        <source>Unselect All</source>
        <translation>Desselecionar tudo</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>Cancelar</translation>
    </message>
    <message>
        <source>Restore</source>
        <translation>Restaurar</translation>
    </message>
    <message>
        <source>Delete</source>
        <translation>Excluir</translation>
    </message>
    <message>
        <source>All</source>
        <translation>Tudo</translation>
    </message>
    <message>
        <source>Photos</source>
        <translation>Fotos</translation>
    </message>
    <message>
        <source>Videos</source>
        <translation>Vídeos</translation>
    </message>
    <message>
        <source>No results</source>
        <translation>Não há resultados</translation>
    </message>
    <message>
        <source>Favorite</source>
        <translation>Favorito</translation>
    </message>
    <message>
        <source>Rotate counterclockwise</source>
        <translation>Girar no sentido anti-horário</translation>
    </message>
    <message>
        <source>Rotate clockwise</source>
        <translation>Girar no sentido horário</translation>
    </message>
    <message>
        <source>Importing...</source>
        <translation>Importando...</translation>
    </message>
    <message>
        <source>%1/%2 items imported</source>
        <translation>%1/%2 itens importados</translation>
    </message>
    <message>
        <source>%1/%2 items deleted</source>
        <translation>%1/%2 itens excluídos</translation>
    </message>
    <message>
        <source>%1 items imported, %2 items failed</source>
        <translation>%1 itens importados, %2 itens falharam</translation>
    </message>
    <message>
        <source>1 photo selected</source>
        <translation>1 foto selecionada</translation>
    </message>
    <message>
        <source>1 video selected</source>
        <translation>1 vídeo selecionado</translation>
    </message>
    <message>
        <source>The photo/video already exists</source>
        <translation>A foto/vídeo já existe</translation>
    </message>
    <message numerus="yes">
        <source>%n photos selected</source>
        <translation>
            <numerusform>%n foto selecionada</numerusform>
            <numerusform>%n fotos selecionadas</numerusform>
        </translation>
    </message>
    <message numerus="yes">
        <source>%n videos selected</source>
        <translation>
            <numerusform>%n vídeo selecionado</numerusform>
            <numerusform>%n vídeos selecionados</numerusform>
        </translation>
    </message>
    <message numerus="yes">
        <source>%n items selected</source>
        <translation>
            <numerusform>%n item selecionado</numerusform>
            <numerusform>%n itens selecionados</numerusform>
        </translation>
    </message>
    <message>
        <source>%1 items imported, %2 items exist already</source>
        <translation>%1 itens importados, %2 itens já existem</translation>
    </message>
    <message>
        <source>%1/%2 items classifyed</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Scenery</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Food</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Humans</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Animals</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Scene</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Plants</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Items</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Other</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>SearchView</name>
    <message>
        <source>No search results</source>
        <translation>Nenhum resultado encontrado</translation>
    </message>
    <message>
        <source>Slide Show</source>
        <translation>Apresentação de Slides</translation>
    </message>
    <message>
        <source>Search results</source>
        <translation>Resultados da pesquisa</translation>
    </message>
    <message>
        <source>1 photo found</source>
        <translation>1 foto encontrada</translation>
    </message>
    <message numerus="yes">
        <source>%n videos found</source>
        <translation>
            <numerusform>%n vídeo encontrado</numerusform>
            <numerusform>%n vídeos encontrados</numerusform>
        </translation>
    </message>
    <message>
        <source>1 video found</source>
        <translation>1 vídeo encontrado</translation>
    </message>
    <message numerus="yes">
        <source>%n items found</source>
        <translation>
            <numerusform>%n item encontrado</numerusform>
            <numerusform>%n itens encontrados</numerusform>
        </translation>
    </message>
    <message numerus="yes">
        <source>%n photos found</source>
        <translation>
            <numerusform>%n foto encontrada</numerusform>
            <numerusform>%n fotos encontradas</numerusform>
        </translation>
    </message>
</context>
<context>
    <name>StatusBar</name>
    <message>
        <source>1 photo</source>
        <translation>1 foto</translation>
    </message>
    <message>
        <source>1 video</source>
        <translation>1 vídeo</translation>
    </message>
    <message numerus="yes">
        <source>%n photos</source>
        <translation>
            <numerusform>%n foto</numerusform>
            <numerusform>%n fotos</numerusform>
        </translation>
    </message>
    <message numerus="yes">
        <source>%n videos</source>
        <translation>
            <numerusform>%n vídeo</numerusform>
            <numerusform>%n vídeos</numerusform>
        </translation>
    </message>
    <message>
        <source>Importing: %1</source>
        <translation>Importando: %1</translation>
    </message>
    <message>
        <source>Exporting: %1</source>
        <translation>Exportando: %1</translation>
    </message>
</context>
<context>
    <name>ThumbnailListView</name>
    <message>
        <source>View</source>
        <translation>Visualizar</translation>
    </message>
    <message>
        <source>Fullscreen</source>
        <translation>Tela Cheia</translation>
    </message>
    <message>
        <source>Export</source>
        <translation>Exportar</translation>
    </message>
    <message>
        <source>Favorite</source>
        <translation>Favorito</translation>
    </message>
    <message>
        <source>Unfavorite</source>
        <translation>Remover dos Favoritos</translation>
    </message>
    <message>
        <source>Rotate clockwise</source>
        <translation>Girar no sentido horário</translation>
    </message>
    <message>
        <source>Rotate counterclockwise</source>
        <translation>Girar no sentido anti-horário</translation>
    </message>
    <message>
        <source>Display in file manager</source>
        <translation>Exibir no Gerenciador de Arquivos</translation>
    </message>
    <message>
        <source>Set as wallpaper</source>
        <translation>Definir como papel de parede</translation>
    </message>
    <message>
        <source>Delete</source>
        <translation>Excluir</translation>
    </message>
    <message>
        <source>Slide show</source>
        <translation>Apresentação de Slides</translation>
    </message>
    <message>
        <source>Copy</source>
        <translation>Copiar</translation>
    </message>
    <message>
        <source>Photo info</source>
        <translation>Informações da foto</translation>
    </message>
    <message>
        <source>Add to album</source>
        <translation>Adicionar ao álbum</translation>
    </message>
    <message>
        <source>Remove from album</source>
        <translation>Remover do álbum</translation>
    </message>
    <message>
        <source>Restore</source>
        <translation>Restaurar</translation>
    </message>
    <message>
        <source>New album</source>
        <translation>Novo álbum</translation>
    </message>
    <message>
        <source>Print</source>
        <translation>Imprimir</translation>
    </message>
    <message>
        <source>Video info</source>
        <translation>Detalhes do vídeo</translation>
    </message>
    <message>
        <source>days</source>
        <translation>dias</translation>
    </message>
</context>
<context>
    <name>TimeLineView</name>
    <message>
        <source>1 photo</source>
        <translation>1 foto</translation>
    </message>
    <message>
        <source>1 video</source>
        <translation>1 vídeo</translation>
    </message>
    <message numerus="yes">
        <source>%n photos</source>
        <translation>
            <numerusform>%n foto</numerusform>
            <numerusform>%n fotos</numerusform>
        </translation>
    </message>
    <message numerus="yes">
        <source>%n videos</source>
        <translation>
            <numerusform>%n vídeo</numerusform>
            <numerusform>%n vídeos</numerusform>
        </translation>
    </message>
    <message numerus="yes">
        <source>%n items</source>
        <translation>
            <numerusform>%n item</numerusform>
            <numerusform>%n itens</numerusform>
        </translation>
    </message>
</context>
<context>
    <name>VideoInfoDialog</name>
    <message>
        <source>Basic info</source>
        <translation>Informações básicas</translation>
    </message>
    <message>
        <source>Codec info</source>
        <translation>Detalhes do codec</translation>
    </message>
    <message>
        <source>Audio info</source>
        <translation>Detalhes do áudio</translation>
    </message>
    <message>
        <source>Video CodecID</source>
        <translation>ID do codec de vídeo</translation>
    </message>
    <message>
        <source>Video CodeRate</source>
        <translation>Taxa do vídeo</translation>
    </message>
    <message>
        <source>FPS</source>
        <translation>Quadros Por Segundo</translation>
    </message>
    <message>
        <source>Proportion</source>
        <translation>Proporção</translation>
    </message>
    <message>
        <source>Resolution</source>
        <translation>Resolução</translation>
    </message>
    <message>
        <source>Audio CodecID</source>
        <translation>ID do codec de áudio</translation>
    </message>
    <message>
        <source>Audio CodeRate</source>
        <translation>Taxa do áudio</translation>
    </message>
    <message>
        <source>Audio digit</source>
        <translation>Dígito do áudio</translation>
    </message>
    <message>
        <source>Channels</source>
        <translation>Canais</translation>
    </message>
    <message>
        <source>Channel</source>
        <translation>Canal</translation>
    </message>
    <message>
        <source>Sampling</source>
        <translation>Amostragem</translation>
    </message>
    <message>
        <source>Date modified</source>
        <translation>Última modificação</translation>
    </message>
    <message>
        <source>Type</source>
        <translation>Tipo</translation>
    </message>
    <message>
        <source>File size</source>
        <translation>Tamanho do arquivo</translation>
    </message>
    <message>
        <source>Duration</source>
        <translation>Duração</translation>
    </message>
    <message>
        <source>Path</source>
        <translation>Caminho</translation>
    </message>
    <message>
        <source>Video info</source>
        <translation>Detalhes do vídeo</translation>
    </message>
    <message>
        <source>Date captured</source>
        <translation>Data de captura</translation>
    </message>
    <message>
        <source>Name</source>
        <translation type="unfinished"></translation>
    </message>
</context>
</TS>
